@@ -3,9 +3,10 @@ import subprocess
 
 from service_buddy_too.util.log_handler import print_red_bold
 
+dry_run_global = False
 
-def invoke_process(args, exec_dir=None, dry_run=False):
-    if dry_run:
+def invoke_process(args, exec_dir=None):
+    if dry_run_global:
         print_red_bold(u"\t {}".format(str(args)))
         return 0
     else:
@@ -14,7 +15,7 @@ def invoke_process(args, exec_dir=None, dry_run=False):
         if exec_dir:
             arg_list['cwd'] = exec_dir
 
-        logging.info(u'[exec] invoke_process args=%r, exec_dir=%r, dry_run=%r', args, exec_dir, dry_run)
+        logging.info(u'[exec] invoke_process args=%r, exec_dir=%r, dry_run=%r', args, exec_dir, dry_run_global)
         returncode = 0
         try:
             output = subprocess.check_output(**arg_list)
@@ -24,6 +25,6 @@ def invoke_process(args, exec_dir=None, dry_run=False):
 
         for line in output.splitlines():
             logging.info(u'[exec] %s', line)
-        logging.info(u'[exec] invoke_process complete args=%r, exec_dir=%r, dry_run=%r', args, exec_dir, dry_run)
+        logging.info(u'[exec] invoke_process complete args=%r, exec_dir=%r, dry_run=%r', args, exec_dir, dry_run_global)
 
         return returncode
